/* This file is part of Lemma, a geophysical modelling and inversion API.
 * More information is available at http://lemmasoftware.org
 */

/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

/**
 * @file
 * @date      03/21/2016 02:10:08 PM
 * @version   $Id$
 * @author    Trevor Irons (ti)
 * @email     tirons@egi.utah.edu
 * @copyright Copyright (c) 2016, University of Utah
 * @copyright Copyright (c) 2016, Lemma Software, LLC
 */

#include "LinearMag.h"

namespace Lemma {

// ====================  FRIEND METHODS  =====================
#ifdef HAVE_YAMLCPP
std::ostream &operator << (std::ostream &stream, const LinearMag &ob) {
    stream << ob.Serialize()  << "\n---\n"; // End of doc --- as a direct stream should encapsulate thingy
    return stream;
}
#else
std::ostream &operator<<(std::ostream &stream, const LinearMag& ob) {
    stream << *(FEM4EllipticPDE*)(&ob);
    return stream;
}
#endif

// ====================  LIFECYCLE     =======================

//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  LinearMag
// Description:  constructor (protected)
//--------------------------------------------------------------------------------------
LinearMag::LinearMag (const std::string& name) : FEM4EllipticPDE(name) {

}  // -----  end of method LinearMag::LinearMag  (constructor)  -----

#ifdef HAVE_YAMLCPP
//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  LinearMag
// Description:  DeSerializing constructor (protected)
//--------------------------------------------------------------------------------------
LinearMag::LinearMag (const YAML::Node& node) : FEM4EllipticPDE(node) {

}  // -----  end of method LinearMag::LinearMag  (constructor)  -----
#endif

//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  New()
// Description:  public constructor
//--------------------------------------------------------------------------------------
LinearMag* LinearMag::New() {
    LinearMag*  Obj = new LinearMag("LinearMag");
    Obj->AttachTo(Obj);
    return Obj;
}

//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  ~LinearMag
// Description:  destructor (protected)
//--------------------------------------------------------------------------------------
LinearMag::~LinearMag () {

}  // -----  end of method LinearMag::~LinearMag  (destructor)  -----

//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  Delete
// Description:  public destructor
//--------------------------------------------------------------------------------------
void LinearMag::Delete() {
    this->DetachFrom(this);
}

//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  Release
// Description:  destructor (protected)
//--------------------------------------------------------------------------------------
void LinearMag::Release() {
    delete this;
}


#ifdef HAVE_YAMLCPP
//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  Serialize
//--------------------------------------------------------------------------------------
YAML::Node  LinearMag::Serialize (  ) const {
    YAML::Node node = FEM4EllipticPDE::Serialize();;
    node.SetTag( this->Name );
    // FILL IN CLASS SPECIFICS HERE
    return node;
}		// -----  end of method LinearMag::Serialize  -----


//--------------------------------------------------------------------------------------
//       Class:  LinearMag
//      Method:  DeSerialize
//--------------------------------------------------------------------------------------
LinearMag* LinearMag::DeSerialize ( const YAML::Node& node  ) {
    LinearMag* Object = new LinearMag(node);
    Object->AttachTo(Object);
    DESERIALIZECHECK( node, Object )
        return Object ;
}		// -----  end of method LinearMag::DeSerialize  -----
#endif

}		// -----  end of Lemma  name  -----
